import * as firebase from 'firebase-admin';
/**
 * The UserRecord passed to Cloud Functions is the same UserRecord that is returned by the Firebase Admin
 * SDK.
 */
export declare type UserRecord = firebase.auth.UserRecord;
/**
 * UserInfo that is part of the UserRecord
 */
export declare type UserInfo = firebase.auth.UserInfo;
/**
 * Helper class to create the user metadata in a UserRecord object
 */
export declare class UserRecordMetadata implements firebase.auth.UserMetadata {
    creationTime: string;
    lastSignInTime: string;
    constructor(creationTime: string, lastSignInTime: string);
    /** Returns a plain JavaScript object with the properties of UserRecordMetadata. */
    toJSON(): {
        creationTime: string;
        lastSignInTime: string;
    };
}
/**
 * Helper function that creates a UserRecord Class from data sent over the wire.
 * @param wireData data sent over the wire
 * @returns an instance of UserRecord with correct toJSON functions
 */
export declare function userRecordConstructor(wireData: Object): UserRecord;
